Matrix Function - MFN

slepc-3.18.0 2022-10-01
Report Typos and Errors

## Matrix Function - MFN: Examples

Matrix Function (MFN) is the object provided by SLEPc for computing the action of a matrix function on a vector. Given a matrix A and a vector b, the call `MFNSolve(mfn,b,x)` computes x=f(A)b, where f is a function such as the exponential.

ex23.c: Computes exp(t*A)*v for a matrix associated with a Markov model
ex23f90.F90: Computes exp(t*A)*v for a matrix from a Markov model.
ex26.c: Computes the action of the square root of the 2-D Laplacian
ex37.c: Computes exp(t*A)*v for an advection diffusion operator with Peclet number
ex39.c: Exponential integrator for the heat equation with source term